@@ -1,13 +1,16 @@
-#!/bin/sh
+#!/bin/bash
 umask 0002
 
 id
 
+. /secret-file-loader.sh
+. /reach_database.sh
+
 # Allow for bind-mount multiple settings.py overrides
 FILES=$(ls /app/docker/extra_settings/* 2>/dev/null)
 NUM_FILES=$(echo "$FILES" | wc -w)
 if [ "$NUM_FILES" -gt 0 ]; then
-    COMMA_LIST=$(echo $FILES | tr -s '[:blank:]' ', ')
+    COMMA_LIST=$(echo "$FILES" | tr -s '[:blank:]' ', ')
     echo "============================================================"
     echo "     Overriding DefectDojo's local_settings.py with multiple"
     echo "     Files: $COMMA_LIST"
@@ -16,17 +19,14 @@ if [ "$NUM_FILES" -gt 0 ]; then
     rm -f /app/dojo/settings/README.md
 fi
 
-echo -n "Waiting for database to be reachable "
-until echo "select 1;" | python3 manage.py dbshell > /dev/null
-do
-  echo -n "."
-  sleep 1
-done
+wait_for_database_to_be_reachable
 echo
 
 if [ "${DD_CELERY_WORKER_POOL_TYPE}" = "prefork" ]; then
-  EXTRA_PARAMS="--autoscale=${DD_CELERY_WORKER_AUTOSCALE_MAX},${DD_CELERY_WORKER_AUTOSCALE_MIN}
-    --prefetch-multiplier=${DD_CELERY_WORKER_PREFETCH_MULTIPLIER}"
+  EXTRA_PARAMS=("--autoscale=${DD_CELERY_WORKER_AUTOSCALE_MAX},${DD_CELERY_WORKER_AUTOSCALE_MIN}"
+    "--prefetch-multiplier=${DD_CELERY_WORKER_PREFETCH_MULTIPLIER}")
+else
+  EXTRA_PARAMS=()
 fi
 
 # do the check with Django stack
@@ -36,5 +36,5 @@ exec celery --app=dojo \
     worker \
   --loglevel="${DD_CELERY_LOG_LEVEL}" \
   --pool="${DD_CELERY_WORKER_POOL_TYPE}" \
-  --concurrency=${DD_CELERY_WORKER_CONCURRENCY:-1} \
-  ${EXTRA_PARAMS}
+  --concurrency="${DD_CELERY_WORKER_CONCURRENCY:-1}" \
+  "${EXTRA_PARAMS[@]}"
\ No newline at end of file
