@@ -1,14 +1,16 @@
 #!/bin/sh
 
+. /secret-file-loader.sh
 
-cd /app
+
+cd /app || exit
 
 # Full list of uwsgi options: https://uwsgi-docs.readthedocs.io/en/latest/Options.html
 # --lazy-apps required for debugging --> https://uwsgi-docs.readthedocs.io/en/latest/articles/TheArtOfGracefulReloading.html?highlight=lazy-apps#preforking-vs-lazy-apps-vs-lazy
 
 DD_UWSGI_LOGFORMAT_DEFAULT='[pid: %(pid)|app: -|req: -/-] %(addr) (%(dd_user)) {%(vars) vars in %(pktsize) bytes} [%(ctime)] %(method) %(uri) => generated %(rsize) bytes in %(msecs) msecs (%(proto) %(status)) %(headers) headers in %(hsize) bytes (%(switches) switches on core %(core))'
 
-if [ ${DD_DEBUG} == "True" ]; then
+if [ "${DD_DEBUG}" = "True" ]; then
   echo "Debug mode enabled, reducing # of processes and threads to 1"
   DD_UWSGI_NUM_OF_PROCESSES=1
   DD_UWSGI_NUM_OF_THREADS=1
@@ -19,8 +21,8 @@ exec uwsgi \
   --protocol uwsgi \
   --wsgi dojo.wsgi:application \
   --enable-threads \
-  --processes ${DD_UWSGI_NUM_OF_PROCESSES:-2} \
-  --threads ${DD_UWSGI_NUM_OF_THREADS:-2} \
+  --processes "${DD_UWSGI_NUM_OF_PROCESSES:-2}" \
+  --threads "${DD_UWSGI_NUM_OF_THREADS:-2}" \
   --reload-mercy 1 \
   --worker-reload-mercy 1 \
   --py-autoreload 1 \
