@@ -1,26 +1,27 @@
+import logging
 import os
+
 from celery import Celery
 from celery.signals import setup_logging
 from django.conf import settings
-import logging
 
 logger = logging.getLogger(__name__)
 
 # set the default Django settings module for the 'celery' program.
-os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'dojo.settings.settings')
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "dojo.settings.settings")
 
-app = Celery('dojo')
+app = Celery("dojo")
 
 # Using a string here means the worker will not have to
 # pickle the object when using Windows.
-app.config_from_object('django.conf:settings', namespace='CELERY')
+app.config_from_object("django.conf:settings", namespace="CELERY")
 
 app.autodiscover_tasks(lambda: settings.INSTALLED_APPS)
 
 
 @app.task(bind=True)
 def debug_task(self):
-    print(('Request: {0!r}'.format(self.request)))
+    logger.info(f"Request: {self.request!r}")
 
 
 @setup_logging.connect
