@@ -3,15 +3,16 @@ import logging
 
 from django.db.models.signals import pre_save
 from django.dispatch import receiver
-from dojo.models import Engagement
+
 import dojo.jira_link.helper as jira_helper
+from dojo.models import Engagement
 
 logger = logging.getLogger(__name__)
 
 
 def close_engagement(eng):
     eng.active = False
-    eng.status = 'Completed'
+    eng.status = "Completed"
     eng.save()
 
     if jira_helper.get_jira_project(eng):
@@ -20,7 +21,7 @@ def close_engagement(eng):
 
 def reopen_engagement(eng):
     eng.active = True
-    eng.status = 'In Progress'
+    eng.status = "In Progress"
     eng.save()
 
 
