@@ -1,18 +1,30 @@
+import logging
+from time import strftime
+
+from django.conf import settings
 from django.db.models.query_utils import Q
 from django.db.models.signals import post_delete, pre_delete
 from django.dispatch.dispatcher import receiver
+from django.utils import timezone
+from fieldsignals import pre_save_changed
+
+import dojo.jira_link.helper as jira_helper
 from dojo.celery import app
 from dojo.decorators import dojo_async_task, dojo_model_from_id, dojo_model_to_id
-import logging
-from time import strftime
-from django.utils import timezone
-from django.conf import settings
-from fieldsignals import pre_save_changed
-from dojo.utils import get_current_user, mass_model_updater, to_str_typed
-from dojo.models import Engagement, Finding, Finding_Group, System_Settings, Test, Endpoint, Endpoint_Status, \
-    Vulnerability_Id, Vulnerability_Id_Template
 from dojo.endpoint.utils import save_endpoints_to_add
-
+from dojo.models import (
+    Endpoint,
+    Endpoint_Status,
+    Engagement,
+    Finding,
+    Finding_Group,
+    System_Settings,
+    Test,
+    Vulnerability_Id,
+    Vulnerability_Id_Template,
+)
+from dojo.notes.helper import delete_related_notes
+from dojo.utils import get_current_user, mass_model_updater, to_str_typed
 
 logger = logging.getLogger(__name__)
 deduplicationLogger = logging.getLogger("dojo.specific-loggers.deduplication")
@@ -40,7 +52,7 @@ def pre_save_finding_status_change(sender, instance, changed_fields=None, **kwar
     #     logger.debug('ignoring save of finding without id')
     #     return
 
-    logger.debug('%i: changed status fields pre_save: %s', instance.id or 0, changed_fields)
+    logger.debug("%i: changed status fields pre_save: %s", instance.id or 0, changed_fields)
 
     for field, (old, new) in changed_fields.items():
         logger.debug("%i: %s changed from %s to %s" % (instance.id or 0, field, old, new))
@@ -51,17 +63,29 @@ def pre_save_finding_status_change(sender, instance, changed_fields=None, **kwar
 
 
 # also get signal when id is set/changed so we can process new findings
-pre_save_changed.connect(pre_save_finding_status_change, sender=Finding, fields=['id', 'active', 'verfied', 'false_p', 'is_mitigated', 'mitigated', 'mitigated_by', 'out_of_scope', 'risk_accepted'])
-# pre_save_changed.connect(pre_save_finding_status_change, sender=Finding)
-# post_save_changed.connect(pre_save_finding_status_change, sender=Finding, fields=['active', 'verfied', 'false_p', 'is_mitigated', 'mitigated', 'mitigated_by', 'out_of_scope'])
+pre_save_changed.connect(
+    pre_save_finding_status_change,
+    sender=Finding,
+    fields=[
+        "id",
+        "active",
+        "verified",
+        "false_p",
+        "is_mitigated",
+        "mitigated",
+        "mitigated_by",
+        "out_of_scope",
+        "risk_accepted",
+    ],
+)
 
 
 def update_finding_status(new_state_finding, user, changed_fields=None):
     now = timezone.now()
 
-    logger.debug('changed fields: %s', changed_fields)
+    logger.debug("changed fields: %s", changed_fields)
 
-    is_new_finding = not changed_fields or (changed_fields and len(changed_fields) == 1 and 'id' in changed_fields)
+    is_new_finding = not changed_fields or (changed_fields and len(changed_fields) == 1 and "id" in changed_fields)
 
     # activated
     # reactivated
@@ -71,11 +95,11 @@ def update_finding_status(new_state_finding, user, changed_fields=None):
     # marked as duplicate
     # marked as original
 
-    if is_new_finding or 'is_mitigated' in changed_fields:
+    if is_new_finding or "is_mitigated" in changed_fields:
         # finding is being mitigated
         if new_state_finding.is_mitigated:
             # when mitigating a finding, the meta fields can only be editted if allowed
-            logger.debug('finding being mitigated, set mitigated and mitigated_by fields')
+            logger.debug("finding being mitigated, set mitigated and mitigated_by fields")
 
             if can_edit_mitigated_data(user):
                 # only set if it was not already set by user
@@ -94,7 +118,7 @@ def update_finding_status(new_state_finding, user, changed_fields=None):
         new_state_finding.mitigated = new_state_finding.mitigated or now
         new_state_finding.mitigated_by = new_state_finding.mitigated_by or user
 
-    if is_new_finding or 'active' in changed_fields:
+    if is_new_finding or "active" in changed_fields:
         # finding is being (re)activated
         if new_state_finding.active:
             new_state_finding.false_p = False
@@ -106,10 +130,10 @@ def update_finding_status(new_state_finding, user, changed_fields=None):
             # finding is being deactivated
             pass
 
-    if is_new_finding or 'verified' in changed_fields:
+    if is_new_finding or "verified" in changed_fields:
         pass
 
-    if is_new_finding or 'false_p' in changed_fields or 'out_of_scope' in changed_fields:
+    if is_new_finding or "false_p" in changed_fields or "out_of_scope" in changed_fields:
         # existing behaviour is that false_p or out_of_scope implies mitigated
         if new_state_finding.false_p or new_state_finding.out_of_scope:
             new_state_finding.mitigated = new_state_finding.mitigated or now
@@ -131,11 +155,12 @@ def can_edit_mitigated_data(user):
 
 
 def create_finding_group(finds, finding_group_name):
-    logger.debug('creating finding_group_create')
+    logger.debug("creating finding_group_create")
     if not finds or len(finds) == 0:
-        raise ValueError('cannot create empty Finding Group')
+        msg = "cannot create empty Finding Group"
+        raise ValueError(msg)
 
-    finding_group_name_dummy = 'bulk group ' + strftime("%a, %d %b  %Y %X", timezone.now().timetuple())
+    finding_group_name_dummy = "bulk group " + strftime("%a, %d %b  %Y %X", timezone.now().timetuple())
 
     finding_group = Finding_Group(test=finds[0].test)
     finding_group.creator = get_current_user()
@@ -166,6 +191,11 @@ def add_to_finding_group(finding_group, finds):
     available_findings = [find for find in finds if not find.finding_group_set.all()]
     finding_group.findings.add(*available_findings)
 
+    # Now update the JIRA to add the finding to the finding group
+    if finding_group.has_jira_issue and jira_helper.get_jira_instance(finding_group).finding_jira_sync:
+        logger.debug("pushing to jira from finding.finding_bulk_update_all()")
+        jira_helper.push_to_jira(finding_group)
+
     added = len(available_findings)
     skipped = len(finds) - added
     return finding_group, added, skipped
@@ -187,6 +217,12 @@ def remove_from_finding_group(finds):
 
         removed += 1
 
+    # Now update the JIRA to remove the finding from the finding group
+    for group in affected_groups:
+        if group.has_jira_issue and jira_helper.get_jira_instance(group).finding_jira_sync:
+            logger.debug("pushing to jira from finding.finding_bulk_update_all()")
+            jira_helper.push_to_jira(group)
+
     return affected_groups, removed, skipped
 
 
@@ -195,28 +231,38 @@ def update_finding_group(finding, finding_group):
     if finding_group is not None:
         if finding_group != finding.finding_group:
             if finding.finding_group:
-                logger.debug('removing finding %d from finding_group %s', finding.id, finding.finding_group)
+                logger.debug("removing finding %d from finding_group %s", finding.id, finding.finding_group)
                 finding.finding_group.findings.remove(finding)
-            logger.debug('adding finding %d to finding_group %s', finding.id, finding_group)
+            logger.debug("adding finding %d to finding_group %s", finding.id, finding_group)
             finding_group.findings.add(finding)
     else:
         if finding.finding_group:
-            logger.debug('removing finding %d from finding_group %s', finding.id, finding.finding_group)
+            logger.debug("removing finding %d from finding_group %s", finding.id, finding.finding_group)
             finding.finding_group.findings.remove(finding)
 
 
 def get_group_by_group_name(finding, finding_group_by_option):
-    if finding_group_by_option == 'component_name':
-        group_name = finding.component_name if finding.component_name else 'None'
-    elif finding_group_by_option == 'component_name+component_version':
-        group_name = '%s:%s' % ((finding.component_name if finding.component_name else 'None'),
-        (finding.component_version if finding.component_version else 'None'))
-    elif finding_group_by_option == 'file_path':
-        group_name = 'Filepath %s' % (finding.file_path if finding.file_path else 'None')
-    else:
-        raise ValueError("Invalid group_by option %s" % finding_group_by_option)
+    group_name = None
 
-    return 'Findings in: %s' % group_name
+    if finding_group_by_option == "component_name":
+        group_name = finding.component_name
+    elif finding_group_by_option == "component_name+component_version":
+        if finding.component_name or finding.component_version:
+            group_name = "{}:{}".format((finding.component_name if finding.component_name else "None"),
+                (finding.component_version if finding.component_version else "None"))
+    elif finding_group_by_option == "file_path":
+        if finding.file_path:
+            group_name = f"Filepath {finding.file_path}"
+    elif finding_group_by_option == "finding_title":
+        group_name = finding.title
+    else:
+        msg = f"Invalid group_by option {finding_group_by_option}"
+        raise ValueError(msg)
+
+    if group_name:
+        return f"Findings in: {group_name}"
+
+    return group_name
 
 
 def group_findings_by(finds, finding_group_by_option):
@@ -231,7 +277,11 @@ def group_findings_by(finds, finding_group_by_option):
             continue
 
         group_name = get_group_by_group_name(find, finding_group_by_option)
-        finding_group = Finding_Group.objects.filter(name=group_name).first()
+        if group_name is None:
+            skipped += 1
+            continue
+
+        finding_group = Finding_Group.objects.filter(test=find.test, name=group_name).first()
         if not finding_group:
             finding_group, added, skipped = create_finding_group([find], group_name)
             groups_created += 1
@@ -244,26 +294,61 @@ def group_findings_by(finds, finding_group_by_option):
 
         affected_groups.add(finding_group)
 
+    # Now update the JIRA to add the finding to the finding group
+    for group in affected_groups:
+        if group.has_jira_issue and jira_helper.get_jira_instance(group).finding_jira_sync:
+            logger.debug("pushing to jira from finding.finding_bulk_update_all()")
+            jira_helper.push_to_jira(group)
+
     return affected_groups, grouped, skipped, groups_created
 
 
-def add_finding_to_auto_group(finding, group_by, **kwargs):
-    test = finding.test
-    name = get_group_by_group_name(finding, group_by)
-    creator = get_current_user()
-    if not creator:
-        creator = kwargs.get('async_user', None)
-    finding_group, created = Finding_Group.objects.get_or_create(test=test, creator=creator, name=name)
-    if created:
-        logger.debug('Created Finding Group %d:%s for test %d:%s', finding_group.id, finding_group, test.id, test)
-    finding_group.findings.add(finding)
+def add_findings_to_auto_group(name, findings, group_by, create_finding_groups_for_all_findings=True, **kwargs):
+    if name is not None and findings is not None and len(findings) > 0:
+        creator = get_current_user()
+        if not creator:
+            creator = kwargs.get("async_user", None)
+        test = findings[0].test
+
+        if create_finding_groups_for_all_findings or len(findings) > 1:
+            # Only create a finding group if we have more than one finding for a given finding group, unless configured otherwise
+            finding_group, created = Finding_Group.objects.get_or_create(test=test, creator=creator, name=name)
+            if created:
+                logger.debug("Created Finding Group %d:%s for test %d:%s", finding_group.id, finding_group, test.id, test)
+                # See if we have old findings in the same test that were created without a finding group
+                # that should be added to this new group
+                old_findings = Finding.objects.filter(test=test)
+                for f in old_findings:
+                    f_group_name = get_group_by_group_name(f, group_by)
+                    if f_group_name == name and f not in findings:
+                        finding_group.findings.add(f)
+
+            finding_group.findings.add(*findings)
+        else:
+            # Otherwise add to an existing finding group if it exists only
+            try:
+                finding_group = Finding_Group.objects.get(test=test, name=name)
+                if finding_group:
+                    finding_group.findings.add(*findings)
+            except:
+                # See if we have old findings in the same test that were created without a finding group
+                # that match this new finding - then we can create a finding group
+                old_findings = Finding.objects.filter(test=test)
+                created = False
+                for f in old_findings:
+                    f_group_name = get_group_by_group_name(f, group_by)
+                    if f_group_name == name and f not in findings:
+                        finding_group, created = Finding_Group.objects.get_or_create(test=test, creator=creator, name=name)
+                        finding_group.findings.add(f)
+                if created:
+                    finding_group.findings.add(*findings)
 
 
 @dojo_model_to_id
 @dojo_async_task
 @app.task
 @dojo_model_from_id
-def post_process_finding_save(finding, dedupe_option=True, false_history=False, rules_option=True, product_grading_option=True,
+def post_process_finding_save(finding, dedupe_option=True, rules_option=True, product_grading_option=True,
              issue_updater_option=True, push_to_jira=False, user=None, *args, **kwargs):
 
     system_settings = System_Settings.objects.get()
@@ -279,12 +364,13 @@ def post_process_finding_save(finding, dedupe_option=True, false_history=False,
         else:
             deduplicationLogger.warning("skipping dedupe because hash_code is None")
 
-    if false_history:
-        if system_settings.false_positive_history:
+    if system_settings.false_positive_history:
+        # Only perform false positive history if deduplication is disabled
+        if system_settings.enable_deduplication:
+            deduplicationLogger.warning("skipping false positive history because deduplication is also enabled")
+        else:
             from dojo.utils import do_false_positive_history
             do_false_positive_history(finding, *args, **kwargs)
-        else:
-            deduplicationLogger.debug("skipping false positive history because it's disabled in system settings")
 
     # STEP 2 run all non-status changing tasks as celery tasks in the background
     if issue_updater_option:
@@ -300,7 +386,7 @@ def post_process_finding_save(finding, dedupe_option=True, false_history=False,
 
     # Adding a snippet here for push to JIRA so that it's in one place
     if push_to_jira:
-        logger.debug('pushing finding %s to jira from finding.save()', finding.pk)
+        logger.debug("pushing finding %s to jira from finding.save()", finding.pk)
         import dojo.jira_link.helper as jira_helper
 
         # current approach is that whenever a finding is in a group, the group will be pushed to JIRA
@@ -314,15 +400,15 @@ def post_process_finding_save(finding, dedupe_option=True, false_history=False,
 
 @receiver(pre_delete, sender=Finding)
 def finding_pre_delete(sender, instance, **kwargs):
-    logger.debug('finding pre_delete: %d', instance.id)
+    logger.debug("finding pre_delete: %d", instance.id)
     # this shouldn't be necessary as Django should remove any Many-To-Many entries automatically, might be a bug in Django?
     # https://code.djangoproject.com/ticket/154
-
     instance.found_by.clear()
+    delete_related_notes(instance)
 
 
 def finding_delete(instance, **kwargs):
-    logger.debug('finding delete, instance: %s', instance.id)
+    logger.debug("finding delete, instance: %s", instance.id)
 
     # the idea is that the engagement/test pre delete already prepared all the duplicates inside
     # the test/engagement to no longer point to any original so they can be safely deleted.
@@ -330,7 +416,7 @@ def finding_delete(instance, **kwargs):
     # a manual / single finding delete, or a bulke delete of findings
     # in which case we have to process all the duplicates
     # TODO: should we add the prepocessing also to the bulk edit form?
-    logger.debug('finding_delete: refresh from db: pk: %d', instance.pk)
+    logger.debug("finding_delete: refresh from db: pk: %d", instance.pk)
 
     try:
         instance.refresh_from_db()
@@ -343,17 +429,17 @@ def finding_delete(instance, **kwargs):
     if duplicate_cluster:
         reconfigure_duplicate_cluster(instance, duplicate_cluster)
     else:
-        logger.debug('no duplicate cluster found for finding: %d, so no need to reconfigure', instance.id)
+        logger.debug("no duplicate cluster found for finding: %d, so no need to reconfigure", instance.id)
 
     # this shouldn't be necessary as Django should remove any Many-To-Many entries automatically, might be a bug in Django?
     # https://code.djangoproject.com/ticket/154
-    logger.debug('finding delete: clearing found by')
+    logger.debug("finding delete: clearing found by")
     instance.found_by.clear()
 
 
 @receiver(post_delete, sender=Finding)
 def finding_post_delete(sender, instance, **kwargs):
-    logger.debug('finding post_delete, sender: %s instance: %s', to_str_typed(sender), to_str_typed(instance))
+    logger.debug("finding post_delete, sender: %s instance: %s", to_str_typed(sender), to_str_typed(instance))
     # calculate_grade(instance.test.engagement.product)
 
 
@@ -363,7 +449,7 @@ def reset_duplicate_before_delete(dupe):
 
 
 def reset_duplicates_before_delete(qs):
-    mass_model_updater(Finding, qs, lambda f: reset_duplicate_before_delete(f), fields=['duplicate', 'duplicate_finding'])
+    mass_model_updater(Finding, qs, lambda f: reset_duplicate_before_delete(f), fields=["duplicate", "duplicate_finding"])
 
 
 def set_new_original(finding, new_original):
@@ -381,17 +467,18 @@ def reconfigure_duplicate_cluster(original, cluster_outside):
         return
 
     if settings.DUPLICATE_CLUSTER_CASCADE_DELETE:
-        cluster_outside.order_by('-id').delete()
+        cluster_outside.order_by("-id").delete()
     else:
-        logger.debug('reconfigure_duplicate_cluster: cluster_outside: %s', cluster_outside)
+        logger.debug("reconfigure_duplicate_cluster: cluster_outside: %s", cluster_outside)
         # set new original to first finding in cluster (ordered by id)
-        new_original = cluster_outside.order_by('id').first()
+        new_original = cluster_outside.order_by("id").first()
         if new_original:
-            logger.debug('changing original of duplicate cluster %d to: %s:%s', original.id, new_original.id, new_original.title)
+            logger.debug("changing original of duplicate cluster %d to: %s:%s", original.id, new_original.id, new_original.title)
 
             new_original.duplicate = False
             new_original.duplicate_finding = None
-            new_original.active = True
+            new_original.active = original.active
+            new_original.is_mitigated = original.is_mitigated
             new_original.save_no_options()
             new_original.found_by.set(original.found_by.all())
 
@@ -402,13 +489,13 @@ def reconfigure_duplicate_cluster(original, cluster_outside):
             #         find.duplicate_finding = new_original
             #         find.save_no_options()
 
-            mass_model_updater(Finding, cluster_outside, lambda f: set_new_original(f, new_original), fields=['duplicate_finding'])
+            mass_model_updater(Finding, cluster_outside, lambda f: set_new_original(f, new_original), fields=["duplicate_finding"])
 
 
 def prepare_duplicates_for_delete(test=None, engagement=None):
-    logger.debug('prepare duplicates for delete, test: %s, engagement: %s', test.id if test else None, engagement.id if engagement else None)
+    logger.debug("prepare duplicates for delete, test: %s, engagement: %s", test.id if test else None, engagement.id if engagement else None)
     if test is None and engagement is None:
-        logger.warn('nothing to prepare as test and engagement are None')
+        logger.warning("nothing to prepare as test and engagement are None")
 
     fix_loop_duplicates()
 
@@ -423,7 +510,7 @@ def prepare_duplicates_for_delete(test=None, engagement=None):
     originals = originals.distinct()
 
     if len(originals) == 0:
-        logger.debug('no originals found, so no duplicates to prepare for deletion of original')
+        logger.debug("no originals found, so no duplicates to prepare for deletion of original")
         return
 
     # remove the link to the original from the duplicates inside the cluster so they can be safely deleted by the django framework
@@ -432,7 +519,7 @@ def prepare_duplicates_for_delete(test=None, engagement=None):
     # logger.debug('originals: %s', [original.id for original in originals])
     for original in originals:
         i += 1
-        logger.debug('%d/%d: preparing duplicate cluster for deletion of original: %d', i, total, original.id)
+        logger.debug("%d/%d: preparing duplicate cluster for deletion of original: %d", i, total, original.id)
         cluster_inside = original.original_finding.all()
         if engagement:
             cluster_inside = cluster_inside.filter(test__engagement=engagement)
@@ -454,29 +541,29 @@ def prepare_duplicates_for_delete(test=None, engagement=None):
         if len(cluster_outside) > 0:
             reconfigure_duplicate_cluster(original, cluster_outside)
 
-        logger.debug('done preparing duplicate cluster for deletion of original: %d', original.id)
+        logger.debug("done preparing duplicate cluster for deletion of original: %d", original.id)
 
 
 @receiver(pre_delete, sender=Test)
 def test_pre_delete(sender, instance, **kwargs):
-    logger.debug('test pre_delete, sender: %s instance: %s', to_str_typed(sender), to_str_typed(instance))
+    logger.debug("test pre_delete, sender: %s instance: %s", to_str_typed(sender), to_str_typed(instance))
     prepare_duplicates_for_delete(test=instance)
 
 
 @receiver(post_delete, sender=Test)
 def test_post_delete(sender, instance, **kwargs):
-    logger.debug('test post_delete, sender: %s instance: %s', to_str_typed(sender), to_str_typed(instance))
+    logger.debug("test post_delete, sender: %s instance: %s", to_str_typed(sender), to_str_typed(instance))
 
 
 @receiver(pre_delete, sender=Engagement)
 def engagement_pre_delete(sender, instance, **kwargs):
-    logger.debug('engagement pre_delete, sender: %s instance: %s', to_str_typed(sender), to_str_typed(instance))
+    logger.debug("engagement pre_delete, sender: %s instance: %s", to_str_typed(sender), to_str_typed(instance))
     prepare_duplicates_for_delete(engagement=instance)
 
 
 @receiver(post_delete, sender=Engagement)
 def engagement_post_delete(sender, instance, **kwargs):
-    logger.debug('engagement post_delete, sender: %s instance: %s', to_str_typed(sender), to_str_typed(instance))
+    logger.debug("engagement post_delete, sender: %s instance: %s", to_str_typed(sender), to_str_typed(instance))
 
 
 def fix_loop_duplicates():
@@ -488,7 +575,7 @@ def fix_loop_duplicates():
 
     if loop_count > 0:
         deduplicationLogger.info("Identified %d Findings with Loops" % len(candidates))
-        for find_id in candidates.values_list('id', flat=True):
+        for find_id in candidates.values_list("id", flat=True):
             removeLoop(find_id, 50)
 
         new_originals = Finding.objects.filter(duplicate_finding__isnull=True, duplicate=True)
@@ -548,29 +635,27 @@ def add_endpoints(new_finding, form):
     for endpoint in added_endpoints:
         endpoint_ids.append(endpoint.id)
 
-    new_finding.endpoints.set(form.cleaned_data['endpoints'] | Endpoint.objects.filter(id__in=endpoint_ids))
+    new_finding.endpoints.set(form.cleaned_data["endpoints"] | Endpoint.objects.filter(id__in=endpoint_ids))
 
     for endpoint in new_finding.endpoints.all():
-        eps, created = Endpoint_Status.objects.get_or_create(
+        _eps, _created = Endpoint_Status.objects.get_or_create(
             finding=new_finding,
-            endpoint=endpoint, defaults={'date': form.cleaned_data['date'] or now})
-        endpoint.endpoint_status.add(eps)
-        new_finding.endpoint_status.add(eps)
+            endpoint=endpoint, defaults={"date": form.cleaned_data["date"] or timezone.now()})
 
 
 def save_vulnerability_ids(finding, vulnerability_ids):
     # Remove duplicates
     vulnerability_ids = list(dict.fromkeys(vulnerability_ids))
 
-    previous_vulnerability_ids = set(Vulnerability_Id.objects.filter(finding=finding))
-    for vulnerability_id in vulnerability_ids:
-        obj, created = Vulnerability_Id.objects.get_or_create(
-            finding=finding, vulnerability_id=vulnerability_id)
-        if not created:
-            previous_vulnerability_ids.remove(obj)
-    for vulnerability_id in previous_vulnerability_ids:
-        vulnerability_id.delete()
+    # Remove old vulnerability ids
+    Vulnerability_Id.objects.filter(finding=finding).delete()
 
+    # Save new vulnerability ids
+    # Using bulk create throws Django 50 warnings about unsaved models...
+    for vulnerability_id in vulnerability_ids:
+        Vulnerability_Id(finding=finding, vulnerability_id=vulnerability_id).save()
+
+    # Set CVE
     if vulnerability_ids:
         finding.cve = vulnerability_ids[0]
     else:
@@ -581,15 +666,14 @@ def save_vulnerability_ids_template(finding_template, vulnerability_ids):
     # Remove duplicates
     vulnerability_ids = list(dict.fromkeys(vulnerability_ids))
 
-    previous_vulnerability_ids = set(Vulnerability_Id_Template.objects.filter(finding_template=finding_template))
-    for vulnerability_id in vulnerability_ids:
-        obj, created = Vulnerability_Id_Template.objects.get_or_create(
-            finding_template=finding_template, vulnerability_id=vulnerability_id)
-        if not created:
-            previous_vulnerability_ids.remove(obj)
-    for vulnerability_id in previous_vulnerability_ids:
-        vulnerability_id.delete()
+    # Remove old vulnerability ids
+    Vulnerability_Id_Template.objects.filter(finding_template=finding_template).delete()
 
+    # Save new vulnerability ids
+    for vulnerability_id in vulnerability_ids:
+        Vulnerability_Id_Template(finding_template=finding_template, vulnerability_id=vulnerability_id).save()
+
+    # Set CVE
     if vulnerability_ids:
         finding_template.cve = vulnerability_ids[0]
     else:
