@@ -1,6 +1,6 @@
 import logging
-from django.core.management.base import BaseCommand
 
+from django.core.management.base import BaseCommand
 
 logger = logging.getLogger(__name__)
 
@@ -12,7 +12,7 @@ class Command(BaseCommand):
     authorization is removed from the code now, this management command is
     empty. It cannot be removed because it is called in a db migration.
     """
-    help = 'Usage: manage.py migration_authorization_v2'
+    help = "Usage: manage.py migration_authorization_v2"
 
     def handle(self, *args, **options):
         pass
