@@ -1,8 +1,8 @@
 import logging
+
 from django.core.management.base import BaseCommand
 from django.db import connection
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -11,10 +11,10 @@ class Command(BaseCommand):
     Textquestions for surveys need to be modified after loading the fixture
     as they contain an instance dependant polymorphic content id
     """
-    help = 'Usage: manage.py migration_textquestions'
+    help = "Usage: manage.py migration_textquestions"
 
     def handle(self, *args, **options):
-        logger.info('Started migrating textquestions ...')
+        logger.info("Started migrating textquestions ...")
 
         update_textquestions = """UPDATE dojo_question
 SET polymorphic_ctype_id = (
@@ -29,4 +29,4 @@ WHERE
         with connection.cursor() as cursor:
             cursor.execute(update_textquestions)
 
-        logger.info('Finished migrating textquestions')
+        logger.info("Finished migrating textquestions")
