@@ -1,15 +1,19 @@
-from django.core.management.base import BaseCommand
-from django.conf import settings
+import logging
 import os
-from pprint import pprint
+from pprint import pformat
+
+from django.conf import settings
+from django.core.management.base import BaseCommand
+
+logger = logging.getLogger(__name__)
 
 
 class Command(BaseCommand):
-    help = 'Display all the currently loaded settings in the project'
+    help = "Display all the currently loaded settings in the project"
 
     def handle(self, *args, **options):
 
-        os.environ['DJANGO_SETTINGS_MODULE'] = 'my_django_project.settings'
+        os.environ["DJANGO_SETTINGS_MODULE"] = "my_django_project.settings"
 
         a_dict = {}
 
@@ -17,4 +21,4 @@ class Command(BaseCommand):
             value = getattr(settings, attr)
             a_dict[attr] = value
 
-        pprint(a_dict)
+        logging.info(pformat(a_dict))
