@@ -1,4 +1,5 @@
 from django.core.management.base import BaseCommand
+
 from dojo.utils import sla_compute_and_notify
 
 """
@@ -7,7 +8,7 @@ This command will iterate over findings and send SLA notifications as appropriat
 
 
 class Command(BaseCommand):
-    help = 'Launch with no argument.'
+    help = "Launch with no argument."
 
     def handle(self, *args, **options):
         sla_compute_and_notify()
