@@ -1,9 +1,10 @@
 from django.core.management.base import BaseCommand
+
 from dojo.models import System_Settings
 
 
 class Command(BaseCommand):
-    help = 'Updates product grade calculation'
+    help = "Updates product grade calculation"
 
     def handle(self, *args, **options):
         code = """def grade_product(crit, high, med, low):
