@@ -733,6 +733,61 @@ function accepted_per_week_2(critical, high, medium, low) {
         product_metrics.html
 */
 
+function open_findings_burndown(critical, high, medium, low, info, y_max, y_min) {
+    var options = {
+        xaxes: [{
+            mode: "time",
+            timeformat: "%Y/%m/%d"
+        }],
+        yaxes: [{
+            max: y_max,
+            min: y_min
+        }],
+        series: {
+            lines: {
+                show: true
+            },
+            points: {
+                show: true,
+                radius: 1
+            }
+        },
+        grid: {
+            hoverable: true,
+            borderWidth: 1,
+            borderColor: '#e7e7e7',
+    
+        },
+        legend: {
+            position: 'nw'
+        },
+        tooltip: true,
+    };
+
+    var plotObj = $.plot($("#open_findings_burndown"), [{
+                data: critical,
+                label: " Critical",
+                color: "#d9534f",
+            }, {
+                data: high,
+                label: " High",
+                color: '#f0ad4e',
+            }, {
+                data: medium,
+                label: " Medium",
+                color: '#f0de28',
+            }, {
+                data: low,
+                label: " Low",
+                color: '#4cae4c',
+            }, {
+                data: info,
+                label: " Info",
+                color: '#337ab7',
+            }],
+            options);
+}
+
 function accepted_objs(d1, d2, d3, d4, d5, ticks) {
     var data = [
         {
@@ -1563,8 +1618,6 @@ function open_close_weekly(opened, closed, accepted, ticks) {
     var options = {
         xaxes: [{
             ticks: ticks,
-            transform: function(v) { return -v; },
-            inverseTransform: function(v) { return -v; }
         }],
         yaxes: [{
             min: 0
@@ -1606,8 +1659,6 @@ function severity_weekly(critical, high, medium, low, info, ticks) {
     var options = {
         xaxes: [{
             ticks: ticks,
-            transform: function(v) { return -v; },
-            inverseTransform: function(v) { return -v; }
         }],
         yaxes: [{
             min: 0
@@ -1658,8 +1709,6 @@ function severity_counts_weekly(critical, high, medium, ticks) {
     var options = {
         xaxes: [{
             ticks: ticks,
-            transform: function(v) { return -v; },
-            inverseTransform: function(v) { return -v; }
         }],
         yaxes: [{
             min: 0
@@ -1980,7 +2029,8 @@ function languages_pie(data) {
             }
         },
         legend: {
-            show: true
+            show: true,
+            container: "#donut-lang-container",
         },
         grid: {
             hoverable: true,
