@@ -1,8 +1,9 @@
-from django import template
 import crum
+from django import template
+
+from dojo.authorization.authorization import user_has_configuration_permission as configuration_permission
+from dojo.authorization.authorization import user_has_global_permission, user_has_permission
 from dojo.authorization.roles_permissions import Permissions
-from dojo.authorization.authorization import user_has_global_permission, user_has_permission, \
-    user_has_configuration_permission as configuration_permission
 from dojo.request_cache import cache_for_request
 
 register = template.Library()
@@ -19,8 +20,12 @@ def has_global_permission(permission):
 
 
 @register.filter
-def has_configuration_permission(permission, legacy):
-    return configuration_permission(crum.get_current_user(), permission, legacy)
+def has_configuration_permission(permission, request):
+    if request is None:
+        user = crum.get_current_user()
+    else:
+        user = crum.get_current_user() or request.user
+    return configuration_permission(user, permission)
 
 
 @cache_for_request
@@ -48,3 +53,11 @@ def group_has_configuration_permission(group, codename):
         if permission.codename == codename:
             return True
     return False
+
+
+@register.simple_tag
+def user_can_clear_peer_review(finding, user):
+    finding_under_review = finding.under_review
+    user_requesting_review = user == finding.review_requested_by
+    user_is_reviewer = user in finding.reviewers.all()
+    return finding_under_review and (user_requesting_review or user_is_reviewer)
