@@ -1,10 +1,12 @@
 from django import template
+
 register = template.Library()
 
+
 @register.filter
 def get_attribute(obj, name):
 
     if hasattr(obj, name):
         return getattr(obj, name)
     else:
-        return ''
\ No newline at end of file
+        return ""
