@@ -2,7 +2,7 @@ from .parser_json import SSLyzeJSONParser
 from .parser_xml import SSLyzeXMLParser
 
 
-class SslyzeParser(object):
+class SslyzeParser:
     """SSLyze support JSON and XML"""
 
     def get_scan_types(self):
@@ -17,13 +17,13 @@ class SslyzeParser(object):
         return "Import XML report of SSLyze version 2 scan."
 
     def get_findings(self, filename, test):
-
         if filename is None:
-            return list()
+            return []
 
-        if filename.name.lower().endswith('.xml'):
+        if filename.name.lower().endswith(".xml"):
             return SSLyzeXMLParser().get_findings(filename, test)
-        elif filename.name.lower().endswith('.json'):
+        elif filename.name.lower().endswith(".json"):
             return SSLyzeJSONParser().get_findings(filename, test)
         else:
-            raise Exception('Unknown File Format')
+            msg = "Unknown File Format"
+            raise ValueError(msg)
