@@ -1,8 +1,6 @@
 from dojo.celery import app
-
-from dojo.decorators import (dojo_async_task, dojo_model_from_id,
-                             dojo_model_to_id)
-from dojo.tools.sonarqube_api.parser import SCAN_SONARQUBE_API
+from dojo.decorators import dojo_async_task, dojo_model_from_id, dojo_model_to_id
+from dojo.tools.api_sonarqube.parser import SCAN_SONARQUBE_API
 
 
 def async_tool_issue_update(finding, *args, **kwargs):
@@ -24,15 +22,14 @@ def tool_issue_updater(finding, *args, **kwargs):
     test_type = finding.test.test_type
 
     if test_type.name == SCAN_SONARQUBE_API:
-        from dojo.tools.sonarqube_api.updater import SonarQubeApiUpdater
+        from dojo.tools.api_sonarqube.updater import SonarQubeApiUpdater
         SonarQubeApiUpdater().update_sonarqube_finding(finding)
 
 
 @dojo_async_task
 @app.task
 def update_findings_from_source_issues(**kwargs):
-    from dojo.tools.sonarqube_api.updater_from_source import \
-        SonarQubeApiUpdaterFromSource
+    from dojo.tools.api_sonarqube.updater_from_source import SonarQubeApiUpdaterFromSource
 
     findings = SonarQubeApiUpdaterFromSource().get_findings_to_update()
 
