@@ -1,7 +1,8 @@
+import sys
 import unittest
+
 from base_test_class import BaseTestCase
 from selenium.webdriver.common.by import By
-import sys
 
 
 class VariousPagesTest(BaseTestCase):
@@ -18,9 +19,9 @@ class VariousPagesTest(BaseTestCase):
 
 def suite():
     suite = unittest.TestSuite()
-    suite.addTest(BaseTestCase('test_login'))
-    suite.addTest(VariousPagesTest('test_user_status'))
-    suite.addTest(VariousPagesTest('test_calendar_status'))
+    suite.addTest(BaseTestCase("test_login"))
+    suite.addTest(VariousPagesTest("test_user_status"))
+    suite.addTest(VariousPagesTest("test_calendar_status"))
     return suite
 
 
