@@ -4,15 +4,13 @@ import sys
 import time
 import unittest
 
+from base_test_class import BaseTestCase, on_exception_html_source_logger, set_suite_settings
+from product_test import ProductTest
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import Select, WebDriverWait
 
-from base_test_class import (BaseTestCase, on_exception_html_source_logger,
-                             set_suite_settings)
-from product_test import ProductTest
-
 logger = logging.getLogger(__name__)
 
 dir_path = os.path.dirname(os.path.realpath(__file__))
@@ -24,22 +22,20 @@ class DedupeTest(BaseTestCase):
     # --------------------------------------------------------------------------------------------------------
     def setUp(self):
         super().setUp()
-        self.relative_path = dir_path = os.path.dirname(os.path.realpath(__file__))
+        self.relative_path = os.path.dirname(os.path.realpath(__file__))
 
     def check_nb_duplicates(self, expected_number_of_duplicates):
         logger.debug("checking duplicates...")
         driver = self.driver
-        retries = 0
-        for i in range(0, 18):
+        for i in range(18):
             time.sleep(5)  # wait bit for celery dedupe task which can be slow on travis
             self.goto_all_findings_list(driver)
             dupe_count = 0
             # iterate over the rows of the findings table and concatenates all columns into td.text
             trs = driver.find_elements(By.XPATH, '//*[@id="open_findings"]/tbody/tr')
             for row in trs:
-                concatRow = ' '.join([td.text for td in row.find_elements(By.XPATH, ".//td")])
-                # print(concatRow)
-                if '(DUPE)' and 'Duplicate' in concatRow:
+                concatRow = " ".join([td.text for td in row.find_elements(By.XPATH, ".//td")])
+                if "(DUPE)" and "Duplicate" in concatRow:
                     dupe_count += 1
 
             if (dupe_count != expected_number_of_duplicates):
@@ -48,8 +44,8 @@ class DedupeTest(BaseTestCase):
                 break
 
         if (dupe_count != expected_number_of_duplicates):
-            findings_table = driver.find_element(By.ID, 'open_findings')
-            print(findings_table.get_attribute('innerHTML'))
+            findings_table = driver.find_element(By.ID, "open_findings")
+            logger.debug(findings_table.get_attribute("innerHTML"))
 
         self.assertEqual(dupe_count, expected_number_of_duplicates)
 
@@ -57,14 +53,14 @@ class DedupeTest(BaseTestCase):
     def test_enable_deduplication(self):
         logger.debug("enabling deduplication...")
         driver = self.driver
-        driver.get(self.base_url + 'system_settings')
-        if not driver.find_element(By.ID, 'id_enable_deduplication').is_selected():
+        driver.get(self.base_url + "system_settings")
+        if not driver.find_element(By.ID, "id_enable_deduplication").is_selected():
             driver.find_element(By.XPATH, '//*[@id="id_enable_deduplication"]').click()
             # save settings
             driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
             # check if it's enabled after reload
-            driver.get(self.base_url + 'system_settings')
-            self.assertTrue(driver.find_element(By.ID, 'id_enable_deduplication').is_selected())
+            driver.get(self.base_url + "system_settings")
+            self.assertTrue(driver.find_element(By.ID, "id_enable_deduplication").is_selected())
 
     @on_exception_html_source_logger
     def test_delete_findings(self):
@@ -74,34 +70,33 @@ class DedupeTest(BaseTestCase):
 
         if self.element_exists_by_id("no_findings"):
             text = driver.find_element(By.ID, "no_findings").text
-            if 'No findings found.' in text:
+            if "No findings found." in text:
                 return
 
         driver.find_element(By.ID, "select_all").click()
-        driver.find_element(By.CSS_SELECTOR, "i.fa.fa-trash").click()
+        driver.find_element(By.CSS_SELECTOR, "i.fa-solid.fa-trash").click()
         try:
             WebDriverWait(driver, 1).until(EC.alert_is_present(),
-                                        'Timed out waiting for finding delete ' +
-                                        'confirmation popup to appear.')
+                                        "Timed out waiting for finding delete "
+                                        + "confirmation popup to appear.")
             driver.switch_to.alert.accept()
         except TimeoutException:
-            self.fail('Confirmation dialogue not shown, cannot delete previous findings')
+            self.fail("Confirmation dialogue not shown, cannot delete previous findings")
 
         logger.debug("page source when checking for no_findings element")
         logger.debug(self.driver.page_source)
         text = driver.find_element(By.ID, "no_findings").text
 
         self.assertIsNotNone(text)
-        self.assertTrue('No findings found.' in text)
+        self.assertTrue("No findings found." in text)
         # check that user was redirect back to url where it came from based on return_url
-        self.assertTrue(driver.current_url.endswith('page=1'))
-
+        self.assertTrue(driver.current_url.endswith("page=1"))
 
 # --------------------------------------------------------------------------------------------------------
 # Same scanner deduplication - Deduplication on engagement
 #   Test deduplication for Bandit SAST scanner
 # --------------------------------------------------------------------------------------------------------
-    @on_exception_html_source_logger  # noqa: E301
+    @on_exception_html_source_logger
     def test_add_path_test_suite(self):
         logger.debug("Same scanner deduplication - Deduplication on engagement - static. Creating tests...")
         # Create engagement
@@ -113,7 +108,7 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Add the tests
         # Test 1
         driver.find_element(By.ID, "id_title").send_keys("Path Test 1")
@@ -121,14 +116,14 @@ class DedupeTest(BaseTestCase):
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.NAME, "_Add Another Test").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
         # Test 2
         driver.find_element(By.ID, "id_title").send_keys("Path Test 2")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Bandit Scan")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
     @on_exception_html_source_logger
     def test_import_path_tests(self):
@@ -145,14 +140,11 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        # active and verified:
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_path_1.json")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_path_1.json")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
         # 'Bandit Scan processed a total of 1 findings created 1 findings did not touch 1 findings.'
-        self.assertTrue(self.is_success_message_present(text='a total of 1 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 1 findings"))
 
         # Second test
         # the second report have 2 findings (same vuln_id same file but different line number)
@@ -162,13 +154,11 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_path_2.json")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_path_2.json")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
         # 'Bandit Scan processed a total of 2 findings created 2 findings did not touch 1 findings.'
-        self.assertTrue(self.is_success_message_present(text='a total of 2 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 2 findings"))
 
     @on_exception_html_source_logger
     def test_check_path_status(self):
@@ -194,7 +184,7 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Add the tests
         # Test 1
         driver.find_element(By.ID, "id_title").send_keys("Endpoint Test 1")
@@ -202,14 +192,14 @@ class DedupeTest(BaseTestCase):
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.NAME, "_Add Another Test").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
         # Test 2
         driver.find_element(By.ID, "id_title").send_keys("Endpoint Test 2")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Immuniweb Scan")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
     @on_exception_html_source_logger
     def test_import_endpoint_tests(self):
@@ -222,13 +212,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Endpoint Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        # active and verified
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
         # Second test : Immuniweb Scan (dynamic)
         self.goto_active_engagements_overview(driver)
@@ -236,13 +223,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Endpoint Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        # active and verified
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_2.xml")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_2.xml")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
     @on_exception_html_source_logger
     def test_check_endpoint_status(self):
@@ -264,7 +248,7 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Add the tests
         # Test 1
         driver.find_element(By.ID, "id_title").send_keys("Same Eng Test 1")
@@ -272,32 +256,30 @@ class DedupeTest(BaseTestCase):
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.NAME, "_Add Another Test").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
         # Test 2
         driver.find_element(By.ID, "id_title").send_keys("Same Eng Test 2")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Generic Findings Import")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
     @on_exception_html_source_logger
     def test_import_same_eng_tests(self):
-        logger.debug("Importing reports")
-        # First test : Immuniweb Scan (dynamic)
-
+        """Test different scanners - different engagement - dynamic"""
         driver = self.driver
         self.goto_active_engagements_overview(driver)
+
+        # First test : Immuniweb Scan (dynamic)
         driver.find_element(By.PARTIAL_LINK_TEXT, "Dedupe Same Eng Test").click()
         driver.find_element(By.PARTIAL_LINK_TEXT, "Same Eng Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
         # Second test : Generic Findings Import with Url (dynamic)
         self.goto_active_engagements_overview(driver)
@@ -305,12 +287,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Same Eng Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_cross_1.csv")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_cross_1.csv")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
     @on_exception_html_source_logger
     def test_check_same_eng_status(self):
@@ -338,7 +318,7 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Add the tests
         # Test 1
         driver.find_element(By.ID, "id_title").send_keys("Path Test 1")
@@ -346,14 +326,14 @@ class DedupeTest(BaseTestCase):
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.NAME, "_Add Another Test").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
         # Test 2
         driver.find_element(By.ID, "id_title").send_keys("Path Test 2")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Checkmarx Scan")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
     def test_import_path_tests_checkmarx_scan(self):
         # First test
@@ -364,13 +344,11 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
         # os.path.realpath makes the path canonical
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 2 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 2 findings"))
 
         # Second test
         self.goto_active_engagements_overview(driver)
@@ -378,12 +356,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings_line_changed.xml"))
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings_line_changed.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 2 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 2 findings"))
 
     def test_check_path_status_checkmarx_scan(self):
         # After aggregation, it's only two findings. Both are duplicates even though the line number has changed
@@ -407,14 +383,14 @@ class DedupeTest(BaseTestCase):
         # driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Test
         driver.find_element(By.ID, "id_title").send_keys("Generic Test")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Generic Findings Import")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
         # Create immuniweb engagement
         self.goto_product_overview(driver)
@@ -424,14 +400,14 @@ class DedupeTest(BaseTestCase):
         # driver.find_element(By.XPATH, '//*[@id="id_deduplication_on_engagement"]').click()
         driver.find_element(By.NAME, "_Add Tests").click()
 
-        self.assertTrue(self.is_success_message_present(text='Engagement added successfully.'))
+        self.assertTrue(self.is_success_message_present(text="Engagement added successfully."))
         # Test
         driver.find_element(By.ID, "id_title").send_keys("Immuniweb Test")
         Select(driver.find_element(By.ID, "id_test_type")).select_by_visible_text("Immuniweb Scan")
         Select(driver.find_element(By.ID, "id_environment")).select_by_visible_text("Development")
         driver.find_element(By.CSS_SELECTOR, "input.btn.btn-primary").click()
 
-        self.assertTrue(self.is_success_message_present(text='Test added successfully'))
+        self.assertTrue(self.is_success_message_present(text="Test added successfully"))
 
     def test_import_cross_test(self):
         logger.debug("Importing findings...")
@@ -441,27 +417,23 @@ class DedupeTest(BaseTestCase):
         self.goto_active_engagements_overview(driver)
         driver.find_element(By.PARTIAL_LINK_TEXT, "Dedupe Immuniweb Test").click()
         driver.find_element(By.PARTIAL_LINK_TEXT, "Immuniweb Test").click()
-        driver.find_element(By.CSS_SELECTOR, "b.fa.fa-ellipsis-v").click()
+        driver.find_element(By.CSS_SELECTOR, "i.fa-solid.fa-ellipsis-vertical").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan Results").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_endpoint_1.xml")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
         # Second test : generic scan with url (dynamic)
         self.goto_active_engagements_overview(driver)
         driver.find_element(By.PARTIAL_LINK_TEXT, "Dedupe Generic Test").click()
         driver.find_element(By.PARTIAL_LINK_TEXT, "Generic Test").click()
-        driver.find_element(By.CSS_SELECTOR, "b.fa.fa-ellipsis-v").click()
+        driver.find_element(By.CSS_SELECTOR, "i.fa-solid.fa-ellipsis-vertical").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan Results").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(self.relative_path + "/dedupe_scans/dedupe_cross_1.csv")
+        driver.find_element(By.ID, "id_file").send_keys(self.relative_path + "/dedupe_scans/dedupe_cross_1.csv")
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='a total of 3 findings'))
+        self.assertTrue(self.is_success_message_present(text="a total of 3 findings"))
 
     def test_check_cross_status(self):
         self.check_nb_duplicates(1)
@@ -480,12 +452,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='Checkmarx Scan processed a total of 2 findings created 2 findings.'))
+        self.assertTrue(self.is_success_message_present(text="Checkmarx Scan processed a total of 2 findings created 2 findings."))
 
         # Import the same findings a second time - they should all be duplicates
         self.goto_active_engagements_overview(driver)
@@ -493,12 +463,10 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='Checkmarx Scan processed a total of 2 findings created 2 findings.'))
+        self.assertTrue(self.is_success_message_present(text="Checkmarx Scan processed a total of 2 findings created 2 findings."))
 
     def test_check_no_service(self):
         # Since we imported the same report twice, we should have 2 duplicates
@@ -515,13 +483,11 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 1").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_service').send_keys("service_1")
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
+        driver.find_element(By.ID, "id_service").send_keys("service_1")
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='Checkmarx Scan processed a total of 2 findings created 2 findings.'))
+        self.assertTrue(self.is_success_message_present(text="Checkmarx Scan processed a total of 2 findings created 2 findings."))
 
         # Import the same findings a second time with a different service - they should all be new findings
         self.goto_active_engagements_overview(driver)
@@ -529,13 +495,11 @@ class DedupeTest(BaseTestCase):
         driver.find_element(By.PARTIAL_LINK_TEXT, "Path Test 2").click()
         driver.find_element(By.ID, "dropdownMenu1").click()
         driver.find_element(By.LINK_TEXT, "Re-Upload Scan").click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[3]/div/div').click()
-        driver.find_element(By.XPATH, '//*[@id="base-content"]/form/div[4]/div/div').click()
-        driver.find_element(By.ID, 'id_service').send_keys("service_2")
-        driver.find_element(By.ID, 'id_file').send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
+        driver.find_element(By.ID, "id_service").send_keys("service_2")
+        driver.find_element(By.ID, "id_file").send_keys(os.path.realpath(self.relative_path + "/dedupe_scans/multiple_findings.xml"))
         driver.find_elements(By.CSS_SELECTOR, "button.btn.btn-primary")[1].click()
 
-        self.assertTrue(self.is_success_message_present(text='Checkmarx Scan processed a total of 2 findings created 2 findings.'))
+        self.assertTrue(self.is_success_message_present(text="Checkmarx Scan processed a total of 2 findings created 2 findings."))
 
     def test_check_service(self):
         # Since we imported the same report twice but with different service names, we should have no duplicates
@@ -543,58 +507,58 @@ class DedupeTest(BaseTestCase):
 
 
 def add_dedupe_tests_to_suite(suite, jira=False, github=False, block_execution=False):
-    suite.addTest(BaseTestCase('test_login'))
+    suite.addTest(BaseTestCase("test_login"))
     set_suite_settings(suite, jira=jira, github=github, block_execution=block_execution)
 
     if jira:
-        suite.addTest(BaseTestCase('enable_jira'))
+        suite.addTest(BaseTestCase("enable_jira"))
     else:
-        suite.addTest(BaseTestCase('disable_jira'))
+        suite.addTest(BaseTestCase("disable_jira"))
     if github:
-        suite.addTest(BaseTestCase('enable_github'))
+        suite.addTest(BaseTestCase("enable_github"))
     else:
-        suite.addTest(BaseTestCase('disable_github'))
+        suite.addTest(BaseTestCase("disable_github"))
     if block_execution:
-        suite.addTest(BaseTestCase('enable_block_execution'))
+        suite.addTest(BaseTestCase("enable_block_execution"))
     else:
-        suite.addTest(BaseTestCase('disable_block_execution'))
+        suite.addTest(BaseTestCase("disable_block_execution"))
 
-    suite.addTest(ProductTest('test_create_product'))
-    suite.addTest(DedupeTest('test_enable_deduplication'))
+    suite.addTest(ProductTest("test_create_product"))
+    suite.addTest(DedupeTest("test_enable_deduplication"))
     # Test same scanners - same engagement - static - dedupe
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_add_path_test_suite'))
-    suite.addTest(DedupeTest('test_import_path_tests'))
-    suite.addTest(DedupeTest('test_check_path_status'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_add_path_test_suite"))
+    suite.addTest(DedupeTest("test_import_path_tests"))
+    suite.addTest(DedupeTest("test_check_path_status"))
     # Test same scanners - same engagement - dynamic - dedupe
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_add_endpoint_test_suite'))
-    suite.addTest(DedupeTest('test_import_endpoint_tests'))
-    suite.addTest(DedupeTest('test_check_endpoint_status'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_add_endpoint_test_suite"))
+    suite.addTest(DedupeTest("test_import_endpoint_tests"))
+    suite.addTest(DedupeTest("test_check_endpoint_status"))
     # Test different scanners - same engagement - dynamic - dedupe
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_add_same_eng_test_suite'))
-    suite.addTest(DedupeTest('test_import_same_eng_tests'))
-    suite.addTest(DedupeTest('test_check_same_eng_status'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_add_same_eng_test_suite"))
+    suite.addTest(DedupeTest("test_import_same_eng_tests"))
+    suite.addTest(DedupeTest("test_check_same_eng_status"))
     # Test same scanners - same engagement - static - dedupe with custom hash_code
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_add_path_test_suite_checkmarx_scan'))
-    suite.addTest(DedupeTest('test_import_path_tests_checkmarx_scan'))
-    suite.addTest(DedupeTest('test_check_path_status_checkmarx_scan'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_add_path_test_suite_checkmarx_scan"))
+    suite.addTest(DedupeTest("test_import_path_tests_checkmarx_scan"))
+    suite.addTest(DedupeTest("test_check_path_status_checkmarx_scan"))
     # Test different scanners - different engagement - dynamic - dedupe
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_add_cross_test_suite'))
-    suite.addTest(DedupeTest('test_import_cross_test'))
-    suite.addTest(DedupeTest('test_check_cross_status'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_add_cross_test_suite"))
+    suite.addTest(DedupeTest("test_import_cross_test"))
+    suite.addTest(DedupeTest("test_check_cross_status"))
     # Test deduplication with and without service in findings
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_import_no_service'))
-    suite.addTest(DedupeTest('test_check_no_service'))
-    suite.addTest(DedupeTest('test_delete_findings'))
-    suite.addTest(DedupeTest('test_import_service'))
-    suite.addTest(DedupeTest('test_check_service'))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_import_no_service"))
+    suite.addTest(DedupeTest("test_check_no_service"))
+    suite.addTest(DedupeTest("test_delete_findings"))
+    suite.addTest(DedupeTest("test_import_service"))
+    suite.addTest(DedupeTest("test_check_service"))
     # Clean up
-    suite.addTest(ProductTest('test_delete_product'))
+    suite.addTest(ProductTest("test_delete_product"))
     return suite
 
 
