@@ -1,16 +1,41 @@
+from unittest.mock import patch
+
 from django.contrib.auth.models import User
 from django.core.exceptions import PermissionDenied
-from django.test.utils import override_settings
-from ..dojo_test_case import DojoTestCase
-from unittest.mock import patch
-from dojo.models import Dojo_User, Product_Type, Product_Type_Member, Product, Product_Member, Engagement, \
-    Test, Finding, Endpoint, Dojo_Group, Product_Group, Product_Type_Group, Role, Global_Role, Dojo_Group_Member, \
-    Languages, App_Analysis, Stub_Finding
+
 import dojo.authorization.authorization
-from dojo.authorization.authorization import role_has_permission, get_roles_for_permission, user_has_global_permission, \
-    user_has_permission_or_403, user_has_permission, user_has_configuration_permission, \
-    RoleDoesNotExistError, PermissionDoesNotExistError
+from dojo.authorization.authorization import (
+    PermissionDoesNotExistError,
+    RoleDoesNotExistError,
+    get_roles_for_permission,
+    role_has_permission,
+    user_has_configuration_permission,
+    user_has_global_permission,
+    user_has_permission,
+    user_has_permission_or_403,
+)
 from dojo.authorization.roles_permissions import Permissions, Roles
+from dojo.models import (
+    App_Analysis,
+    Dojo_Group,
+    Dojo_Group_Member,
+    Dojo_User,
+    Endpoint,
+    Engagement,
+    Finding,
+    Global_Role,
+    Languages,
+    Product,
+    Product_Group,
+    Product_Member,
+    Product_Type,
+    Product_Type_Group,
+    Product_Type_Member,
+    Role,
+    Stub_Finding,
+    Test,
+)
+from unittests.dojo_test_case import DojoTestCase
 
 
 class TestAuthorization(DojoTestCase):
@@ -141,7 +166,7 @@ class TestAuthorization(DojoTestCase):
 
     def test_role_has_permission_exception(self):
         with self.assertRaisesMessage(RoleDoesNotExistError,
-                'Role 9999 does not exist'):
+                "Role 9999 does not exist"):
             role_has_permission(9999, Permissions.Product_Type_Edit)
 
     def test_role_has_permission_true(self):
@@ -154,7 +179,7 @@ class TestAuthorization(DojoTestCase):
 
     def test_get_roles_for_permission_exception(self):
         with self.assertRaisesMessage(PermissionDoesNotExistError,
-                'Permission 9999 does not exist'):
+                "Permission 9999 does not exist"):
             get_roles_for_permission(9999)
 
     def test_get_roles_for_permission_success(self):
@@ -166,7 +191,7 @@ class TestAuthorization(DojoTestCase):
         with self.assertRaises(PermissionDenied):
             user_has_permission_or_403(self.user, self.product_type, Permissions.Product_Type_Delete)
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_or_403_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -178,14 +203,14 @@ class TestAuthorization(DojoTestCase):
 
     def test_user_has_permission_exception(self):
         with self.assertRaisesMessage(dojo.authorization.authorization.NoAuthorizationImplementedError,
-                'No authorization implemented for class Product_Type_Member and permission 1007'):
+                "No authorization implemented for class Product_Type_Member and permission 1007"):
             user_has_permission(self.user, self.product_type_member, Permissions.Product_Type_Delete)
 
     def test_user_has_permission_product_type_no_member(self):
         result = user_has_permission(self.user, self.product_type, Permissions.Product_Type_View)
         self.assertFalse(result)
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_product_type_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -205,7 +230,7 @@ class TestAuthorization(DojoTestCase):
 
         self.user.is_superuser = False
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_product_type_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -220,7 +245,7 @@ class TestAuthorization(DojoTestCase):
         result = user_has_permission(self.user, self.product, Permissions.Product_View)
         self.assertFalse(result)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_product_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -231,7 +256,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_product_product_type_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -242,7 +267,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_product_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -253,7 +278,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_engagement_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -264,7 +289,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_engagement_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -275,7 +300,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_test_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -286,7 +311,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_test_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -297,7 +322,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_finding_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -308,7 +333,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_finding_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -319,7 +344,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_stub_finding_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -330,7 +355,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_stub_finding_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -341,7 +366,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_endpoint_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -352,7 +377,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_endpoint_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -367,7 +392,7 @@ class TestAuthorization(DojoTestCase):
         result = user_has_permission(self.user, self.product_type_member_owner, Permissions.Product_Type_Member_Delete)
         self.assertTrue(result)
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_product_type_member_no_permission(self, mock_foo):
         other_user = User()
         other_user.id = 2
@@ -385,7 +410,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=other_user)
 
-    @patch('dojo.models.Product_Type_Member.objects')
+    @patch("dojo.models.Product_Type_Member.objects")
     def test_user_has_permission_product_type_member_success(self, mock_foo):
         other_user = User()
         other_user.id = 2
@@ -407,7 +432,7 @@ class TestAuthorization(DojoTestCase):
         result = user_has_permission(self.user, self.product_member_owner, Permissions.Product_Member_Delete)
         self.assertTrue(result)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_product_member_no_permission(self, mock_foo):
         other_user = User()
         other_user.id = 2
@@ -425,7 +450,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=other_user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_product_member_success(self, mock_foo):
         other_user = User()
         other_user.id = 2
@@ -443,7 +468,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=other_user)
 
-    @patch('dojo.models.Product_Group.objects')
+    @patch("dojo.models.Product_Group.objects")
     def test_user_has_group_product_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -454,7 +479,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(group__users=self.user)
 
-    @patch('dojo.models.Product_Group.objects')
+    @patch("dojo.models.Product_Group.objects")
     def test_user_has_group_product_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -465,7 +490,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(group__users=self.user)
 
-    @patch('dojo.models.Product_Type_Group.objects')
+    @patch("dojo.models.Product_Type_Group.objects")
     def test_user_has_group_product_type_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -476,7 +501,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(group__users=self.user)
 
-    @patch('dojo.models.Product_Type_Group.objects')
+    @patch("dojo.models.Product_Type_Group.objects")
     def test_user_has_group_product_type_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -503,7 +528,7 @@ class TestAuthorization(DojoTestCase):
         result = user_has_global_permission(self.user5, Permissions.Product_Type_Add)
         self.assertTrue(result)
 
-    @patch('dojo.models.Dojo_Group.objects')
+    @patch("dojo.models.Dojo_Group.objects")
     def test_user_in_group_with_global_role_no_permission(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -513,7 +538,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(users=self.user3)
 
-    @patch('dojo.models.Dojo_Group.objects')
+    @patch("dojo.models.Dojo_Group.objects")
     def test_user_in_group_with_global_role_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -523,7 +548,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(users=self.user3)
 
-    @patch('dojo.models.Dojo_Group_Member.objects')
+    @patch("dojo.models.Dojo_Group_Member.objects")
     def test_dojo_group_no_permission(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -533,7 +558,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user4)
 
-    @patch('dojo.models.Dojo_Group_Member.objects')
+    @patch("dojo.models.Dojo_Group_Member.objects")
     def test_dojo_group_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -543,7 +568,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user4)
 
-    @patch('dojo.models.Dojo_Group_Member.objects')
+    @patch("dojo.models.Dojo_Group_Member.objects")
     def test_dojo_group_member_no_permission(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -553,7 +578,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user4)
 
-    @patch('dojo.models.Dojo_Group_Member.objects')
+    @patch("dojo.models.Dojo_Group_Member.objects")
     def test_dojo_group_member_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -563,7 +588,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user4)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_language_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -574,7 +599,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_language_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -585,7 +610,7 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_technology_no_permissions(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -596,7 +621,7 @@ class TestAuthorization(DojoTestCase):
         self.assertFalse(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @patch('dojo.models.Product_Member.objects')
+    @patch("dojo.models.Product_Member.objects")
     def test_user_has_permission_technology_success(self, mock_foo):
         mock_foo.select_related.return_value = mock_foo
         mock_foo.select_related.return_value = mock_foo
@@ -607,33 +632,14 @@ class TestAuthorization(DojoTestCase):
         self.assertTrue(result)
         mock_foo.filter.assert_called_with(user=self.user)
 
-    @override_settings(FEATURE_CONFIGURATION_AUTHORIZATION=False)
-    def test_configuration_permission_legacy_staff(self):
-        self.user.is_staff = True
-        self.assertTrue(user_has_configuration_permission(self.user, None, 'staff'))
-        self.user.is_staff = False
-
-    @override_settings(FEATURE_CONFIGURATION_AUTHORIZATION=False)
-    def test_configuration_permission_legacy_superuser(self):
-        self.user.is_superuser = True
-        self.assertTrue(user_has_configuration_permission(self.user, None, 'superuser'))
-        self.user.is_superuser = False
-
-    @override_settings(FEATURE_CONFIGURATION_AUTHORIZATION=False)
-    def test_configuration_permission_legacy_exception(self):
-        with self.assertRaisesMessage(Exception, 'test is not allowed for parameter legacy'):
-            user_has_configuration_permission(self.user, None, 'test')
-
-    @override_settings(FEATURE_CONFIGURATION_AUTHORIZATION=True)
-    @patch('django.contrib.auth.models.User.has_perm')
+    @patch("django.contrib.auth.models.User.has_perm")
     def test_configuration_permission_true(self, mock):
         mock.return_value = True
-        self.assertTrue(user_has_configuration_permission(self.user, 'test', 'test'))
-        mock.assert_called_with('test')
+        self.assertTrue(user_has_configuration_permission(self.user, "test"))
+        mock.assert_called_with("test")
 
-    @override_settings(FEATURE_CONFIGURATION_AUTHORIZATION=True)
-    @patch('django.contrib.auth.models.User.has_perm')
+    @patch("django.contrib.auth.models.User.has_perm")
     def test_configuration_permission_false(self, mock):
         mock.return_value = False
-        self.assertFalse(user_has_configuration_permission(self.user, 'test', 'test'))
-        mock.assert_called_with('test')
+        self.assertFalse(user_has_configuration_permission(self.user, "test"))
+        mock.assert_called_with("test")
