@@ -1,20 +1,22 @@
-from crum import impersonate
-from django.test.utils import override_settings
-from .dojo_test_case import DojoTestCase
-from dojo.utils import set_duplicate
-from dojo.management.commands.fix_loop_duplicates import fix_loop_duplicates
-from dojo.models import Engagement, Finding, Product, User
 import logging
 
+from crum import impersonate
+from django.test.utils import override_settings
+
+from dojo.management.commands.fix_loop_duplicates import fix_loop_duplicates
+from dojo.models import Engagement, Finding, Product, User
+from dojo.utils import set_duplicate
+
+from .dojo_test_case import DojoTestCase
 
 logger = logging.getLogger(__name__)
 
 
 class TestDuplicationLoops(DojoTestCase):
-    fixtures = ['dojo_testdata.json']
+    fixtures = ["dojo_testdata.json"]
 
     def run(self, result=None):
-        testuser = User.objects.get(username='admin')
+        testuser = User.objects.get(username="admin")
         testuser.usercontactinfo.block_execution = True
         testuser.save()
 
@@ -27,21 +29,21 @@ class TestDuplicationLoops(DojoTestCase):
     def setUp(self):
         self.finding_a = Finding.objects.get(id=2)
         self.finding_a.pk = None
-        self.finding_a.title = 'A: ' + self.finding_a.title
+        self.finding_a.title = "A: " + self.finding_a.title
         self.finding_a.duplicate = False
         self.finding_a.duplicate_finding = None
         self.finding_a.hash_code = None
         self.finding_a.save()
         self.finding_b = Finding.objects.get(id=3)
         self.finding_b.pk = None
-        self.finding_b.title = 'B: ' + self.finding_b.title
+        self.finding_b.title = "B: " + self.finding_b.title
         self.finding_b.duplicate = False
         self.finding_b.duplicate_finding = None
         self.finding_b.hash_code = None
         self.finding_b.save()
         self.finding_c = Finding.objects.get(id=4)
         self.finding_c.pk = None
-        self.finding_c.title = 'C: ' + self.finding_c.title
+        self.finding_c.title = "C: " + self.finding_c.title
         self.finding_c.duplicate = False
         self.finding_c.duplicate_finding = None
         self.finding_c.hash_code = None
@@ -119,9 +121,9 @@ class TestDuplicationLoops(DojoTestCase):
     def test_set_duplicate_exception_delete_original_cascade(self):
         set_duplicate(self.finding_a, self.finding_b)
         self.assertEqual(self.finding_b.original_finding.first().id, self.finding_a.id)
-        logger.debug('going to delete finding B')
+        logger.debug("going to delete finding B")
         self.finding_b.delete()
-        logger.debug('deleted finding B')
+        logger.debug("deleted finding B")
         with self.assertRaises(Finding.DoesNotExist):
             self.finding_a = Finding.objects.get(id=self.finding_a.id)
         self.assertEqual(self.finding_b.id, None)
@@ -132,16 +134,17 @@ class TestDuplicationLoops(DojoTestCase):
         set_duplicate(self.finding_a, self.finding_b)
         set_duplicate(self.finding_c, self.finding_b)
         self.assertEqual(self.finding_b.original_finding.first().id, self.finding_a.id)
-        logger.debug('going to delete finding B')
+        logger.debug("going to delete finding B")
+        b_active = self.finding_b.active
         b_id = self.finding_b.id
         self.finding_b.delete()
-        logger.debug('deleted finding B')
+        logger.debug("deleted finding B")
         self.finding_a.refresh_from_db()
         self.finding_c.refresh_from_db()
         self.assertEqual(self.finding_a.original_finding.first(), self.finding_c)
         self.assertEqual(self.finding_a.duplicate_finding, None)
         self.assertEqual(self.finding_a.duplicate, False)
-        self.assertEqual(self.finding_a.active, True)
+        self.assertEqual(self.finding_a.active, b_active)
 
         self.assertEqual(self.finding_c.original_finding.first(), None)
         self.assertEqual(self.finding_c.duplicate_finding, self.finding_a)
@@ -156,15 +159,16 @@ class TestDuplicationLoops(DojoTestCase):
     def test_set_duplicate_exception_delete_original_1_duplicate_adapt(self):
         set_duplicate(self.finding_a, self.finding_b)
         self.assertEqual(self.finding_b.original_finding.first().id, self.finding_a.id)
-        logger.debug('going to delete finding B')
+        logger.debug("going to delete finding B")
+        b_active = self.finding_b.active
         b_id = self.finding_b.id
         self.finding_b.delete()
-        logger.debug('deleted finding B')
+        logger.debug("deleted finding B")
         self.finding_a.refresh_from_db()
         self.assertEqual(self.finding_a.original_finding.first(), None)
         self.assertEqual(self.finding_a.duplicate_finding, None)
         self.assertEqual(self.finding_a.duplicate, False)
-        self.assertEqual(self.finding_a.active, True)
+        self.assertEqual(self.finding_a.active, b_active)
         with self.assertRaises(Finding.DoesNotExist):
             self.finding_b = Finding.objects.get(id=b_id)
 
@@ -376,10 +380,10 @@ class TestDuplicationLoops(DojoTestCase):
 
     def test_delete_all_engagements(self):
         # make sure there is no exception when deleting all engagements
-        for engagement in Engagement.objects.all().order_by('id'):
+        for engagement in Engagement.objects.all().order_by("id"):
             engagement.delete()
 
     def test_delete_all_products(self):
         # make sure there is no exception when deleting all engagements
-        for product in Product.objects.all().order_by('id'):
+        for product in Product.objects.all().order_by("id"):
             product.delete()
