@@ -1,6 +1,7 @@
-from .dojo_test_case import DojoTestCase
 from dojo.models import System_Settings
 
+from .dojo_test_case import DojoTestCase
+
 
 class TestSystemSettings(DojoTestCase):
 
@@ -14,19 +15,14 @@ class TestSystemSettings(DojoTestCase):
         system_settings.enable_jira = True
         system_settings.save()
         system_settings = System_Settings.objects.get()
-        self.assertEquals(system_settings.enable_jira, True)
+        self.assertEqual(system_settings.enable_jira, True)
 
         system_settings.enable_jira = False
         system_settings.save()
         system_settings = System_Settings.objects.get()
-        self.assertEquals(system_settings.enable_jira, False)
+        self.assertEqual(system_settings.enable_jira, False)
 
         system_settings.enable_jira = True
         system_settings.save()
         system_settings = System_Settings.objects.get(no_cache=True)
-        self.assertEquals(system_settings.enable_jira, True)
-
-        system_settings.enable_google_sheets = True
-        system_settings.save()
-        system_settings = System_Settings.objects.get(no_cache=True)
-        self.assertEquals(system_settings.enable_google_sheets, True)
+        self.assertEqual(system_settings.enable_jira, True)
