@@ -1,6 +1,6 @@
-from ..dojo_test_case import DojoTestCase
 from dojo.models import Test
 from dojo.tools.cloudsploit.parser import CloudsploitParser
+from unittests.dojo_test_case import DojoTestCase
 
 
 class TestCloudsploitParser(DojoTestCase):
