@@ -1,6 +1,6 @@
-from ..dojo_test_case import DojoTestCase
 from dojo.models import Test
 from dojo.tools.hadolint.parser import HadolintParser
+from unittests.dojo_test_case import DojoTestCase
 
 
 class TesthadolintParser(DojoTestCase):
