@@ -15,6 +15,11 @@ framework.
 """
 import os
 
+from django.core.wsgi import get_wsgi_application
+from django.urls import get_resolver
+
+from dojo.settings.settings import ROOT_URLCONF
+
 # We defer to a DJANGO_SETTINGS_MODULE already in the environment. This breaks
 # if running multiple sites in the same mod_wsgi process. To fix this, use
 # mod_wsgi daemon mode with each site in its own daemon process, or use
@@ -24,10 +29,7 @@ os.environ.setdefault("DJANGO_SETTINGS_MODULE", "dojo.settings.settings")
 # This application object is used by any WSGI server configured to use this
 # file. This includes Django's development server, if the WSGI_APPLICATION
 # setting points here.
-from django.core.wsgi import get_wsgi_application
-
 application = get_wsgi_application()
 
-# Apply WSGI middleware here.
-# from helloworld.wsgi import HelloWorldApplication
-# application = HelloWorldApplication(application)
+# Preload the application code by preloading the URLs configuration
+get_resolver(ROOT_URLCONF).url_patterns
